pub struct GamescopeInputMethodManager(/* private fields */);Implementations
Sourceimpl GamescopeInputMethodManager
impl GamescopeInputMethodManager
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the input method manager
Destroys the gamescope_input_method_manager object.
The gamescope_input_method objects originating from it remain valid.
This is a destructor, you cannot send requests to this object any longer once this method is called.
Sourcepub fn create_input_method(&self, seat: &WlSeat) -> Main<GamescopeInputMethod>
pub fn create_input_method(&self, seat: &WlSeat) -> Main<GamescopeInputMethod>
create an input method object
Create a new gamescope_input_method object associated with a given seat.