Module gamescope_input_method_manager

Module gamescope_input_method_manager 

input method manager

The input method manager allows the client to become the input method on a chosen seat.

No more than one input method must be associated with any seat at any given time.

Structs

GamescopeInputMethodManager

Enums

Event
Request

Constants

REQ_CREATE_INPUT_METHOD_SINCE
The minimal object version supporting this request
REQ_DESTROY_SINCE
The minimal object version supporting this request

Statics

gamescope_input_method_manager_interface
C representation of this interface, for interop
gamescope_input_method_manager_requests
C-representation of the messages of this interface, for interop