#[non_exhaustive]pub enum Event {}Trait Implementations
Sourceimpl MessageGroup for Event
impl MessageGroup for Event
Sourceconst MESSAGES: &'static [MessageDesc]
const MESSAGES: &'static [MessageDesc]
Wire representation of this MessageGroup
Sourcetype Map = ResourceMap
type Map = ResourceMap
The wrapper type for ObjectMap allowing the mapping of Object and
NewId arguments to the object map during parsing.
Sourcefn is_destructor(&self) -> bool
fn is_destructor(&self) -> bool
Whether this message is a destructor Read more
Sourcefn child<Meta: ObjectMetadata>(
opcode: u16,
version: u32,
meta: &Meta,
) -> Option<Object<Meta>>
fn child<Meta: ObjectMetadata>( opcode: u16, version: u32, meta: &Meta, ) -> Option<Object<Meta>>
Retrieve the child
Object associated with this message if anySourcefn from_raw(msg: Message, map: &mut Self::Map) -> Result<Self, ()>
fn from_raw(msg: Message, map: &mut Self::Map) -> Result<Self, ()>
Construct a message from its raw representation
Sourceunsafe fn from_raw_c(
obj: *mut c_void,
opcode: u32,
args: *const wl_argument,
) -> Result<Event, ()>
unsafe fn from_raw_c( obj: *mut c_void, opcode: u32, args: *const wl_argument, ) -> Result<Event, ()>
Construct a message of this group from its C representation Read more
Sourcefn as_raw_c_in<F, T>(self, f: F) -> T
fn as_raw_c_in<F, T>(self, f: F) -> T
Build a C representation of this message Read more