#[non_exhaustive]pub enum Request {
Destroy,
Commit {
serial: u32,
},
SetString {
text: String,
},
SetAction {
action: Action,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the text input
Destroys the gamescope_text_input object.
This is a destructor, once received this object cannot be used any longer.
Commit
apply state
Apply state changes from set_string and set_action requests.
The state relating to these events is double-buffered, and each one modifies the pending state. This request replaces the current state with the pending state.
The client must set the serial to the last received serial in the done event.
SetString
set string to be committed
Send the string text for insertion to the application.
Inserts a string at current cursor position (see commit event sequence). The string to commit could be either just a single character after a key press or the result of some composing.
Values set with this event are double-buffered. They must be applied and reset to initial on the next gamescope_text_input.commit request.
The initial value of text is an empty string.
SetAction
perform an action
Set the action to be performed on commit.
Values set with this event are double-buffered. They must be applied and reset to initial on the next gamescope_text_input.commit request.